@@ -19,6 +19,8 @@ def add_one(num):
     return num+1
 
 class CustomImageDataset(torch.utils.data.Dataset):
+    ''' Class for importint custom images to use during network training '''
+    
     # Initialize the directory containing the images, the annotation file, and both transforms
     def __init__(self, df, img_dir, transform=None, target_transform=None):
         self.df = df
@@ -52,6 +54,8 @@ class CustomImageDataset(torch.utils.data.Dataset):
 
 #https://pytorch.org/vision/0.8/_modules/torchvision/models/alexnet.html
 class AlexNet(nn.Module):
+    ''' Class to define the network used during training itself ''' 
+    
     def __init__(self, num_classes: int = 1, dropout: float = 0.5) -> None:
         super().__init__()
         #_log_api_usage_once(self)
@@ -101,6 +105,27 @@ def train_model(df, img_dir, name,
     save_directory=False,
     save_visualizations=False):
 
+    '''
+    Trains the model to reproduce results from the manuscript
+
+    Arguments:
+     - df: The dataframe 'stiffnesses.csv'
+     - img_dir: The directory where the squares are stored 
+     - name: The name that will be used during saving (if applicable)
+     - brightness_range: The upper and lower bounds of brightness adjustments. Used to augment data to artificially 'increase' the size of the training data, emphasize relevant features, and prevent overfitting of the training data
+     - contrast_range: The upper and lower bounds of contrast adjustments
+     - sharpness_range: The upper and lower bounds of sharpness adjustments
+     - batch_size: How many samples to run through the model at once when computing the direction to step the model
+     - n_epochs: The number of epochs that the model will be trained over
+     - learning_rate: The step size used to change the model parameters in the direction of the error gradient
+     - weight_decay: Regularization parameter used to prevent model overfitting by reducing all of the network weights each epoch
+     - criterion: The loss/cost function used to compute model errors
+     - save_directory: The directory where training statistics and summary plots will be stored. Note that a value of 'False' means that these will no be saved
+     - save_visualizations: If 'True', will save saliency plots for the best and worst fits in the training and validation data sets. Note that 'save_directory' must be specified for plots to be saved
+    
+    Returns:
+    In addition to saving output plots (if specified), `train_model` returns the trained network.
+    '''
 
     # Side lengths for the original images and the sidelength used for training
     side_length_source = 448
@@ -389,81 +414,84 @@ def train_model(df, img_dir, name,
         ###################################################### Visualizations
         ############################# Save saliency maps for the 5 best and 5 worst samples
         ############################# for the training and validation datasets
-    if save_visualizations == True:
-        network.to("cpu")
+        if save_visualizations == True:
+            network.to("cpu")
 
-        ############################# Plot the top 10 best and worst predicted plots
-        # Make directories
-        if not os.path.isdir(save_directory + name):
-            os.makedirs(save_directory + name)
-            os.makedirs(save_directory + name + '/training/')
-            os.makedirs(save_directory + name + '/training/worst_fits/')
-            os.makedirs(save_directory + name + '/training/best_fits/')
-            os.makedirs(save_directory + name + '/validation/')
-            os.makedirs(save_directory + name + '/validation/worst_fits/')
-            os.makedirs(save_directory + name + '/validation/best_fits/')
-
-        ###################### Validation set
-        # First the worst fits
-        dest = save_directory + name + '/validation/worst_fits/'
-
-        key_list = df_val.head(4)['Key'].tolist()
-        print('Saving worst validation fits')
-        for key in key_list:
-            ####### Visualizations
-            img_path = os.path.join(img_dir, key)
-            print('Saving ' + img_path)
-            visualize_sample(network, img_path, dest)
-
-
-
-
-        # Then the best fits
-        dest = save_directory + name + '/validation/best_fits/'
-
-        key_list = df_val.tail(4)['Key'].tolist()
-        print('Saving best validation fits')
-        for key in key_list:
-            ####### Visualizations
-            img_path = os.path.join(img_dir, key)
-            print('Saving ' + img_path)
-            visualize_sample(network, img_path, dest)
- 
-
-
-
-        ###################### Training set
-        train_predictions = pd.DataFrame({'Ground Truth':train_labels,
-                                          'Predicted Stiffness':train_outputs})
-
-        df_train = pd.merge(df_train, train_predictions, left_on='Stiffness', right_on='Ground Truth')
-
-        df_train['Error'] = abs(df_train['Stiffness'] - df_train['Predicted Stiffness'])**2 # / df_train['Stiffness'] # 
-        df_train = df_train.sort_values('Error', ascending=False)
-
-
-        # First the worst fits
-        dest = save_directory + name + '/training/worst_fits/'
-
-        key_list = df_train.head(4)['Key'].tolist()
-        for key in key_list:
-            ####### Visualizations
-            img_path = os.path.join(img_dir, key)
-            print('Saving ' + img_path)
-            visualize_sample(network, img_path, dest)
-
-
-
-
-        # Then the best fits
-        dest = save_directory + name + '/training/best_fits/'
-
-        key_list = df_train.tail(4)['Key'].tolist()
-        for key in key_list:
-            ####### Visualizations
-            img_path = os.path.join(img_dir, key)
-            print('Saving ' + img_path)
-            visualize_sample(network, img_path, dest)
+            ############################# Plot the top 10 best and worst predicted plots
+            # Make directories
+            if not os.path.isdir(save_directory + name):
+                os.makedirs(save_directory + name)
+                os.makedirs(save_directory + name + '/training/')
+                os.makedirs(save_directory + name + '/training/worst_fits/')
+                os.makedirs(save_directory + name + '/training/best_fits/')
+                os.makedirs(save_directory + name + '/validation/')
+                os.makedirs(save_directory + name + '/validation/worst_fits/')
+                os.makedirs(save_directory + name + '/validation/best_fits/')
+    
+            ###################### Validation set
+            # First the worst fits
+            dest = save_directory + name + '/validation/worst_fits/'
+    
+            key_list = df_val.head(4)['Key'].tolist()
+            print('Saving worst validation fits')
+            for key in key_list:
+                ####### Visualizations
+                img_path = os.path.join(img_dir, key)
+                print('Saving ' + img_path)
+                visualize_sample(network, img_path, dest)
+    
+    
+    
+    
+            # Then the best fits
+            dest = save_directory + name + '/validation/best_fits/'
+    
+            key_list = df_val.tail(4)['Key'].tolist()
+            print('Saving best validation fits')
+            for key in key_list:
+                ####### Visualizations
+                img_path = os.path.join(img_dir, key)
+                print('Saving ' + img_path)
+                visualize_sample(network, img_path, dest)
+     
+    
+    
+    
+            ###################### Training set
+            train_predictions = pd.DataFrame({'Ground Truth':train_labels,
+                                              'Predicted Stiffness':train_outputs})
+    
+            df_train = pd.merge(df_train, train_predictions, left_on='Stiffness', right_on='Ground Truth')
+    
+            df_train['Error'] = abs(df_train['Stiffness'] - df_train['Predicted Stiffness'])**2 # / df_train['Stiffness'] # 
+            df_train = df_train.sort_values('Error', ascending=False)
+    
+    
+            # First the worst fits
+            dest = save_directory + name + '/training/worst_fits/'
+    
+            key_list = df_train.head(4)['Key'].tolist()
+            for key in key_list:
+                ####### Visualizations
+                img_path = os.path.join(img_dir, key)
+                print('Saving ' + img_path)
+                visualize_sample(network, img_path, dest)
+    
+    
+    
+    
+            # Then the best fits
+            dest = save_directory + name + '/training/best_fits/'
+    
+            key_list = df_train.tail(4)['Key'].tolist()
+            for key in key_list:
+                ####### Visualizations
+                img_path = os.path.join(img_dir, key)
+                print('Saving ' + img_path)
+                visualize_sample(network, img_path, dest)
+    if save_directory == False:
+        if save_visualizations == True:
+            print('No visualizations were saved because no save_directory was specified')
 
     return network
 
